## v1.0.0 (2024-10-25)

### BREAKING CHANGE

- Breaking changes will now be hidden from the commit body and will only appear in the breaking change section. The behavior can be controlled with the newly added option `changeup_hide_breaking`. ([ecda657](https://github.com/kmnhan/cz-changeup/commit/ecda657c5667a438fac0f2a2abd410415e50a48e))

  Adds option for hiding breaking changes from commit body in changelog.

### Feat

- add `changeup_hide_breaking` option ([ecda657](https://github.com/kmnhan/cz-changeup/commit/ecda657c5667a438fac0f2a2abd410415e50a48e))

  Adds option for hiding breaking changes from commit body in changelog.

[main a484b4a] bump: version 0.3.0 → 1.0.0
 2 files changed, 15 insertions(+), 1 deletion(-)

